Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HandleFunc ¶
func HandleFunc(aq querier.AgentQuerier) http.HandlerFunc
HandleFunc returns the function which can handle queries issued by agentinfo commands. The handler function populates Antrea agent information to the response.
Types ¶
type AntreaAgentInfoResponse ¶
type AntreaAgentInfoResponse struct {
Version string `json:"version,omitempty"` // Antrea binary version
PodRef corev1.ObjectReference `json:"podRef,omitempty"` // The Pod that Antrea Agent is running in
NodeRef corev1.ObjectReference `json:"nodeRef,omitempty"` // The Node that Antrea Agent is running in
NodeSubnets []string `json:"nodeSubnets,omitempty"` // Node subnets
OVSInfo v1beta1.OVSInfo `json:"ovsInfo,omitempty"` // OVS Information
NetworkPolicyControllerInfo v1beta1.NetworkPolicyControllerInfo `json:"networkPolicyControllerInfo,omitempty"` // Antrea Agent NetworkPolicy information
LocalPodNum int32 `json:"localPodNum,omitempty"` // The number of Pods which the agent is in charge of
AgentConditions []v1beta1.AgentCondition `json:"agentConditions,omitempty"` // Agent condition contains types like AgentHealthy
}
AntreaAgentInfoResponse is the struct for the response of agentinfo command. It includes all fields except meta info from v1beta1.AntreaAgentInfo struct.
func (AntreaAgentInfoResponse) GetAgentConditionStr ¶
func (r AntreaAgentInfoResponse) GetAgentConditionStr() string
func (AntreaAgentInfoResponse) GetTableHeader ¶
func (r AntreaAgentInfoResponse) GetTableHeader() []string
func (AntreaAgentInfoResponse) GetTableRow ¶
func (r AntreaAgentInfoResponse) GetTableRow(maxColumnLength int) []string
func (AntreaAgentInfoResponse) SortRows ¶
func (r AntreaAgentInfoResponse) SortRows() bool
Click to show internal directories.
Click to hide internal directories.