Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HandleFunc ¶
func HandleFunc(mq querier.AgentMulticastInfoQuerier) http.HandlerFunc
HandleFunc returns the function which can handle queries issued by 'antctl get podmulticaststats' command. It will return Pod multicast traffic statistics for the local Node.
Types ¶
type Response ¶
type Response struct {
PodName string `json:"name,omitempty" antctl:"name,Name of the Pod"`
PodNamespace string `json:"podNamespace,omitempty"`
Inbound string `json:"inbound,omitempty"`
Outbound string `json:"outbound,omitempty"`
}
func (Response) GetTableHeader ¶
func (Response) GetTableRow ¶
Click to show internal directories.
Click to hide internal directories.