Documentation
¶
Index ¶
Constants ¶
const NodePortLocalChain = "ANTREA-NODE-PORT-LOCAL"
NodePortLocalChain is the name of the chain in IPTABLES for Node Port Local
Variables ¶
This section is empty.
Functions ¶
func NewIPTableRules ¶
func NewIPTableRules() *iptablesRules
NewIPTableRules retruns a new instance of IPTableRules
Types ¶
type PodNodePort ¶
type PodNodePort struct {
NodePort int
PodPort int
PodIP string
Protocol string
Protocols []string
}
PodNodePort contains the Node Port, Pod IP, Pod Port and Protocols for NodePortLocal.
type PodPortRules ¶
type PodPortRules interface {
Init() error
AddRule(nodePort int, podIP string, podPort int, protocol string) error
DeleteRule(nodePort int, podIP string, podPort int, protocol string) error
DeleteAllRules() error
AddAllRules(nplList []PodNodePort) error
}
PodPortRules is an interface to abstract operations on rules for Pods
func InitRules ¶
func InitRules() PodPortRules
InitRules initializes rules based on the underlying implementation
Click to show internal directories.
Click to hide internal directories.