GO-2026-4461 : Antrea has invalid enforcement order for network policy rules caused by integer overflow in antrea.io/antrea
Discover Packages
antrea.io/antrea
pkg
antctl
transform
rule
package
Version:
v1.2.2
Opens a new window with list of versions in this module.
Published: Aug 17, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
func ObjectTransform(o interface{}) (interface{}, error )
type Response struct {
Direction string `json:"direction,omitempty"`
From peer `json:"from,omitempty"`
To peer `json:"to,omitempty"`
Services []service `json:"services,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.