GO-2026-4461 : Antrea has invalid enforcement order for network policy rules caused by integer overflow in antrea.io/antrea
Discover Packages
antrea.io/antrea
pkg
antctl
transform
version
package
Version:
v1.2.2
Opens a new window with list of versions in this module.
Published: Aug 17, 2021
License: Apache-2.0
Opens a new window with license information.
Imports: 7
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
AgentVersion is the AddonTransform for the version command. This function
will try to parse the response as a AgentVersionResponse and then populate
it with the version of antctl to a transformedVersionResponse object.
type Response struct {
AgentVersion string `json:"agentVersion,omitempty"`
ControllerVersion string `json:"controllerVersion,omitempty"`
AntctlVersion string `json:"antctlVersion,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.