Documentation
¶
Overview ¶
Package stats is the internal version of the Antrea Stats API. Refer to https://github.com/kubernetes/community/blob/master/contributors/devel/sig-architecture/api_changes.md doc for more information.
Index ¶
- Constants
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type AntreaClusterNetworkPolicyStats
- type AntreaClusterNetworkPolicyStatsList
- type AntreaNetworkPolicyStats
- type AntreaNetworkPolicyStatsList
- type MulticastGroup
- type MulticastGroupList
- type NetworkPolicyStats
- type NetworkPolicyStatsList
- type PodReference
- type RuleTrafficStats
- type TrafficStats
Constants ¶
const GroupName = "stats.antrea.io"
GroupName is the group name use in this package
Variables ¶
var ( // SchemeBuilder points to a list of functions added to Scheme. SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme applies all the stored functions to the scheme. AddToScheme = SchemeBuilder.AddToScheme )
var SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type AntreaClusterNetworkPolicyStats ¶
type AntreaClusterNetworkPolicyStats struct {
metav1.TypeMeta
metav1.ObjectMeta
// The traffic stats of the Antrea ClusterNetworkPolicy.
TrafficStats TrafficStats
// The traffic stats of the Antrea ClusterNetworkPolicy rules.
RuleTrafficStats []RuleTrafficStats
}
AntreaClusterNetworkPolicyStats is the statistics of a Antrea ClusterNetworkPolicy.
func (*AntreaClusterNetworkPolicyStats) DeepCopy ¶
func (in *AntreaClusterNetworkPolicyStats) DeepCopy() *AntreaClusterNetworkPolicyStats
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AntreaClusterNetworkPolicyStats.
func (*AntreaClusterNetworkPolicyStats) DeepCopyInto ¶
func (in *AntreaClusterNetworkPolicyStats) DeepCopyInto(out *AntreaClusterNetworkPolicyStats)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AntreaClusterNetworkPolicyStats) DeepCopyObject ¶
func (in *AntreaClusterNetworkPolicyStats) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AntreaClusterNetworkPolicyStatsList ¶
type AntreaClusterNetworkPolicyStatsList struct {
metav1.TypeMeta
metav1.ListMeta
// List of AntreaClusterNetworkPolicyStats.
Items []AntreaClusterNetworkPolicyStats
}
AntreaClusterNetworkPolicyStatsList is a list of AntreaClusterNetworkPolicyStats.
func (*AntreaClusterNetworkPolicyStatsList) DeepCopy ¶
func (in *AntreaClusterNetworkPolicyStatsList) DeepCopy() *AntreaClusterNetworkPolicyStatsList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AntreaClusterNetworkPolicyStatsList.
func (*AntreaClusterNetworkPolicyStatsList) DeepCopyInto ¶
func (in *AntreaClusterNetworkPolicyStatsList) DeepCopyInto(out *AntreaClusterNetworkPolicyStatsList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AntreaClusterNetworkPolicyStatsList) DeepCopyObject ¶
func (in *AntreaClusterNetworkPolicyStatsList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AntreaNetworkPolicyStats ¶
type AntreaNetworkPolicyStats struct {
metav1.TypeMeta
metav1.ObjectMeta
// The traffic stats of the Antrea NetworkPolicy.
TrafficStats TrafficStats
// The traffic stats of the Antrea NetworkPolicy, from rule perspective.
RuleTrafficStats []RuleTrafficStats
}
AntreaNetworkPolicyStats is the statistics of a Antrea NetworkPolicy.
func (*AntreaNetworkPolicyStats) DeepCopy ¶
func (in *AntreaNetworkPolicyStats) DeepCopy() *AntreaNetworkPolicyStats
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AntreaNetworkPolicyStats.
func (*AntreaNetworkPolicyStats) DeepCopyInto ¶
func (in *AntreaNetworkPolicyStats) DeepCopyInto(out *AntreaNetworkPolicyStats)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AntreaNetworkPolicyStats) DeepCopyObject ¶
func (in *AntreaNetworkPolicyStats) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type AntreaNetworkPolicyStatsList ¶
type AntreaNetworkPolicyStatsList struct {
metav1.TypeMeta
metav1.ListMeta
// List of AntreaNetworkPolicyStats.
Items []AntreaNetworkPolicyStats
}
AntreaNetworkPolicyStatsList is a list of AntreaNetworkPolicyStats.
func (*AntreaNetworkPolicyStatsList) DeepCopy ¶
func (in *AntreaNetworkPolicyStatsList) DeepCopy() *AntreaNetworkPolicyStatsList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new AntreaNetworkPolicyStatsList.
func (*AntreaNetworkPolicyStatsList) DeepCopyInto ¶
func (in *AntreaNetworkPolicyStatsList) DeepCopyInto(out *AntreaNetworkPolicyStatsList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*AntreaNetworkPolicyStatsList) DeepCopyObject ¶
func (in *AntreaNetworkPolicyStatsList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MulticastGroup ¶ added in v1.7.0
type MulticastGroup struct {
metav1.TypeMeta
metav1.ObjectMeta
// Group is the IP of the multicast group.
Group string
// Pods is the list of Pods that have joined the multicast group.
Pods []PodReference
}
MulticastGroup contains the mapping between multicast group and Pods.
func (*MulticastGroup) DeepCopy ¶ added in v1.7.0
func (in *MulticastGroup) DeepCopy() *MulticastGroup
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MulticastGroup.
func (*MulticastGroup) DeepCopyInto ¶ added in v1.7.0
func (in *MulticastGroup) DeepCopyInto(out *MulticastGroup)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MulticastGroup) DeepCopyObject ¶ added in v1.7.0
func (in *MulticastGroup) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type MulticastGroupList ¶ added in v1.7.0
type MulticastGroupList struct {
metav1.TypeMeta
metav1.ListMeta
// List of MulticastGroup.
Items []MulticastGroup
}
MulticastGroupList is a list of MulticastGroup.
func (*MulticastGroupList) DeepCopy ¶ added in v1.7.0
func (in *MulticastGroupList) DeepCopy() *MulticastGroupList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MulticastGroupList.
func (*MulticastGroupList) DeepCopyInto ¶ added in v1.7.0
func (in *MulticastGroupList) DeepCopyInto(out *MulticastGroupList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*MulticastGroupList) DeepCopyObject ¶ added in v1.7.0
func (in *MulticastGroupList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NetworkPolicyStats ¶
type NetworkPolicyStats struct {
metav1.TypeMeta
metav1.ObjectMeta
// The traffic stats of the K8s NetworkPolicy.
TrafficStats TrafficStats
}
NetworkPolicyStats is the statistics of a K8s NetworkPolicy.
func (*NetworkPolicyStats) DeepCopy ¶
func (in *NetworkPolicyStats) DeepCopy() *NetworkPolicyStats
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkPolicyStats.
func (*NetworkPolicyStats) DeepCopyInto ¶
func (in *NetworkPolicyStats) DeepCopyInto(out *NetworkPolicyStats)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NetworkPolicyStats) DeepCopyObject ¶
func (in *NetworkPolicyStats) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type NetworkPolicyStatsList ¶
type NetworkPolicyStatsList struct {
metav1.TypeMeta
metav1.ListMeta
// List of NetworkPolicyStats.
Items []NetworkPolicyStats
}
NetworkPolicyStatsList is a list of NetworkPolicyStats.
func (*NetworkPolicyStatsList) DeepCopy ¶
func (in *NetworkPolicyStatsList) DeepCopy() *NetworkPolicyStatsList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new NetworkPolicyStatsList.
func (*NetworkPolicyStatsList) DeepCopyInto ¶
func (in *NetworkPolicyStatsList) DeepCopyInto(out *NetworkPolicyStatsList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*NetworkPolicyStatsList) DeepCopyObject ¶
func (in *NetworkPolicyStatsList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PodReference ¶ added in v1.7.0
type PodReference struct {
// The name of this Pod.
Name string
// The namespace of this Pod.
Namespace string
}
PodReference represents a Pod Reference.
func (*PodReference) DeepCopy ¶ added in v1.7.0
func (in *PodReference) DeepCopy() *PodReference
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PodReference.
func (*PodReference) DeepCopyInto ¶ added in v1.7.0
func (in *PodReference) DeepCopyInto(out *PodReference)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type RuleTrafficStats ¶
type RuleTrafficStats struct {
Name string
TrafficStats TrafficStats
}
RuleTrafficStats contains TrafficStats of single rule inside a NetworkPolicy.
func (*RuleTrafficStats) DeepCopy ¶
func (in *RuleTrafficStats) DeepCopy() *RuleTrafficStats
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new RuleTrafficStats.
func (*RuleTrafficStats) DeepCopyInto ¶
func (in *RuleTrafficStats) DeepCopyInto(out *RuleTrafficStats)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TrafficStats ¶
type TrafficStats struct {
// Packets is the packets count hit by the NetworkPolicy.
Packets int64
// Bytes is the bytes count hit by the NetworkPolicy.
Bytes int64
// Sessions is the sessions count hit by the NetworkPolicy.
Sessions int64
}
TrafficStats contains the traffic stats of a NetworkPolicy.
func (*TrafficStats) DeepCopy ¶
func (in *TrafficStats) DeepCopy() *TrafficStats
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TrafficStats.
func (*TrafficStats) DeepCopyInto ¶
func (in *TrafficStats) DeepCopyInto(out *TrafficStats)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.