Documentation
¶
Overview ¶
This package has the automatically generated clientset.
Index ¶
- type Clientset
- func (c *Clientset) ControlplaneV1beta1() controlplanev1beta1.ControlplaneV1beta1Interface
- func (c *Clientset) ControlplaneV1beta2() controlplanev1beta2.ControlplaneV1beta2Interface
- func (c *Clientset) CrdV1alpha1() crdv1alpha1.CrdV1alpha1Interface
- func (c *Clientset) CrdV1alpha2() crdv1alpha2.CrdV1alpha2Interface
- func (c *Clientset) CrdV1alpha3() crdv1alpha3.CrdV1alpha3Interface
- func (c *Clientset) CrdV1beta1() crdv1beta1.CrdV1beta1Interface
- func (c *Clientset) Discovery() discovery.DiscoveryInterface
- func (c *Clientset) StatsV1alpha1() statsv1alpha1.StatsV1alpha1Interface
- func (c *Clientset) SystemV1beta1() systemv1beta1.SystemV1beta1Interface
- type Interface
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Clientset ¶
type Clientset struct {
*discovery.DiscoveryClient
// contains filtered or unexported fields
}
Clientset contains the clients for groups. Each group has exactly one version included in a Clientset.
func NewForConfig ¶
NewForConfig creates a new Clientset for the given config. If config's RateLimiter is not set and QPS and Burst are acceptable, NewForConfig will generate a rate-limiter in configShallowCopy.
func NewForConfigOrDie ¶
NewForConfigOrDie creates a new Clientset for the given config and panics if there is an error in the config.
func (*Clientset) ControlplaneV1beta1 ¶
func (c *Clientset) ControlplaneV1beta1() controlplanev1beta1.ControlplaneV1beta1Interface
ControlplaneV1beta1 retrieves the ControlplaneV1beta1Client
func (*Clientset) ControlplaneV1beta2 ¶
func (c *Clientset) ControlplaneV1beta2() controlplanev1beta2.ControlplaneV1beta2Interface
ControlplaneV1beta2 retrieves the ControlplaneV1beta2Client
func (*Clientset) CrdV1alpha1 ¶
func (c *Clientset) CrdV1alpha1() crdv1alpha1.CrdV1alpha1Interface
CrdV1alpha1 retrieves the CrdV1alpha1Client
func (*Clientset) CrdV1alpha2 ¶
func (c *Clientset) CrdV1alpha2() crdv1alpha2.CrdV1alpha2Interface
CrdV1alpha2 retrieves the CrdV1alpha2Client
func (*Clientset) CrdV1alpha3 ¶
func (c *Clientset) CrdV1alpha3() crdv1alpha3.CrdV1alpha3Interface
CrdV1alpha3 retrieves the CrdV1alpha3Client
func (*Clientset) CrdV1beta1 ¶
func (c *Clientset) CrdV1beta1() crdv1beta1.CrdV1beta1Interface
CrdV1beta1 retrieves the CrdV1beta1Client
func (*Clientset) Discovery ¶
func (c *Clientset) Discovery() discovery.DiscoveryInterface
Discovery retrieves the DiscoveryClient
func (*Clientset) StatsV1alpha1 ¶
func (c *Clientset) StatsV1alpha1() statsv1alpha1.StatsV1alpha1Interface
StatsV1alpha1 retrieves the StatsV1alpha1Client
func (*Clientset) SystemV1beta1 ¶
func (c *Clientset) SystemV1beta1() systemv1beta1.SystemV1beta1Interface
SystemV1beta1 retrieves the SystemV1beta1Client
type Interface ¶
type Interface interface {
Discovery() discovery.DiscoveryInterface
ControlplaneV1beta1() controlplanev1beta1.ControlplaneV1beta1Interface
ControlplaneV1beta2() controlplanev1beta2.ControlplaneV1beta2Interface
CrdV1alpha1() crdv1alpha1.CrdV1alpha1Interface
CrdV1alpha2() crdv1alpha2.CrdV1alpha2Interface
CrdV1alpha3() crdv1alpha3.CrdV1alpha3Interface
CrdV1beta1() crdv1beta1.CrdV1beta1Interface
StatsV1alpha1() statsv1alpha1.StatsV1alpha1Interface
SystemV1beta1() systemv1beta1.SystemV1beta1Interface
}
Directories
¶
| Path | Synopsis |
|---|---|
|
This package has the automatically generated fake clientset.
|
This package has the automatically generated fake clientset. |
|
This package contains the scheme of the automatically generated clientset.
|
This package contains the scheme of the automatically generated clientset. |
|
typed
|
|
|
controlplane/v1beta1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
controlplane/v1beta1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
controlplane/v1beta2
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
controlplane/v1beta2/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
crd/v1alpha1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
crd/v1alpha1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
crd/v1alpha2
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
crd/v1alpha2/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
crd/v1alpha3
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
crd/v1alpha3/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
crd/v1beta1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
crd/v1beta1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
stats/v1alpha1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
stats/v1alpha1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |
|
system/v1beta1
This package has the automatically generated typed clients.
|
This package has the automatically generated typed clients. |
|
system/v1beta1/fake
Package fake has the automatically generated clients.
|
Package fake has the automatically generated clients. |