Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type ClusterGroupExpansion
- type ClusterGroupInterface
- type ClusterGroupsGetter
- type CrdV1alpha2Client
- func (c *CrdV1alpha2Client) ClusterGroups() ClusterGroupInterface
- func (c *CrdV1alpha2Client) Egresses() EgressInterface
- func (c *CrdV1alpha2Client) ExternalEntities(namespace string) ExternalEntityInterface
- func (c *CrdV1alpha2Client) ExternalIPPools() ExternalIPPoolInterface
- func (c *CrdV1alpha2Client) RESTClient() rest.Interface
- type CrdV1alpha2Interface
- type EgressExpansion
- type EgressInterface
- type EgressesGetter
- type ExternalEntitiesGetter
- type ExternalEntityExpansion
- type ExternalEntityInterface
- type ExternalIPPoolExpansion
- type ExternalIPPoolInterface
- type ExternalIPPoolsGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterGroupExpansion ¶
type ClusterGroupExpansion interface{}
type ClusterGroupInterface ¶
type ClusterGroupInterface interface {
Create(ctx context.Context, clusterGroup *v1alpha2.ClusterGroup, opts v1.CreateOptions) (*v1alpha2.ClusterGroup, error)
Update(ctx context.Context, clusterGroup *v1alpha2.ClusterGroup, opts v1.UpdateOptions) (*v1alpha2.ClusterGroup, error)
UpdateStatus(ctx context.Context, clusterGroup *v1alpha2.ClusterGroup, opts v1.UpdateOptions) (*v1alpha2.ClusterGroup, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha2.ClusterGroup, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha2.ClusterGroupList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha2.ClusterGroup, err error)
ClusterGroupExpansion
}
ClusterGroupInterface has methods to work with ClusterGroup resources.
type ClusterGroupsGetter ¶
type ClusterGroupsGetter interface {
ClusterGroups() ClusterGroupInterface
}
ClusterGroupsGetter has a method to return a ClusterGroupInterface. A group's client should implement this interface.
type CrdV1alpha2Client ¶
type CrdV1alpha2Client struct {
// contains filtered or unexported fields
}
CrdV1alpha2Client is used to interact with features provided by the crd.antrea.io group.
func New ¶
func New(c rest.Interface) *CrdV1alpha2Client
New creates a new CrdV1alpha2Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*CrdV1alpha2Client, error)
NewForConfig creates a new CrdV1alpha2Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *CrdV1alpha2Client
NewForConfigOrDie creates a new CrdV1alpha2Client for the given config and panics if there is an error in the config.
func (*CrdV1alpha2Client) ClusterGroups ¶
func (c *CrdV1alpha2Client) ClusterGroups() ClusterGroupInterface
func (*CrdV1alpha2Client) Egresses ¶
func (c *CrdV1alpha2Client) Egresses() EgressInterface
func (*CrdV1alpha2Client) ExternalEntities ¶
func (c *CrdV1alpha2Client) ExternalEntities(namespace string) ExternalEntityInterface
func (*CrdV1alpha2Client) ExternalIPPools ¶ added in v1.2.0
func (c *CrdV1alpha2Client) ExternalIPPools() ExternalIPPoolInterface
func (*CrdV1alpha2Client) RESTClient ¶
func (c *CrdV1alpha2Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type CrdV1alpha2Interface ¶
type CrdV1alpha2Interface interface {
RESTClient() rest.Interface
ClusterGroupsGetter
EgressesGetter
ExternalEntitiesGetter
ExternalIPPoolsGetter
}
type EgressExpansion ¶
type EgressExpansion interface{}
type EgressInterface ¶
type EgressInterface interface {
Create(ctx context.Context, egress *v1alpha2.Egress, opts v1.CreateOptions) (*v1alpha2.Egress, error)
Update(ctx context.Context, egress *v1alpha2.Egress, opts v1.UpdateOptions) (*v1alpha2.Egress, error)
UpdateStatus(ctx context.Context, egress *v1alpha2.Egress, opts v1.UpdateOptions) (*v1alpha2.Egress, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha2.Egress, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha2.EgressList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha2.Egress, err error)
EgressExpansion
}
EgressInterface has methods to work with Egress resources.
type EgressesGetter ¶
type EgressesGetter interface {
Egresses() EgressInterface
}
EgressesGetter has a method to return a EgressInterface. A group's client should implement this interface.
type ExternalEntitiesGetter ¶
type ExternalEntitiesGetter interface {
ExternalEntities(namespace string) ExternalEntityInterface
}
ExternalEntitiesGetter has a method to return a ExternalEntityInterface. A group's client should implement this interface.
type ExternalEntityExpansion ¶
type ExternalEntityExpansion interface{}
type ExternalEntityInterface ¶
type ExternalEntityInterface interface {
Create(ctx context.Context, externalEntity *v1alpha2.ExternalEntity, opts v1.CreateOptions) (*v1alpha2.ExternalEntity, error)
Update(ctx context.Context, externalEntity *v1alpha2.ExternalEntity, opts v1.UpdateOptions) (*v1alpha2.ExternalEntity, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha2.ExternalEntity, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha2.ExternalEntityList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha2.ExternalEntity, err error)
ExternalEntityExpansion
}
ExternalEntityInterface has methods to work with ExternalEntity resources.
type ExternalIPPoolExpansion ¶ added in v1.2.0
type ExternalIPPoolExpansion interface{}
type ExternalIPPoolInterface ¶ added in v1.2.0
type ExternalIPPoolInterface interface {
Create(ctx context.Context, externalIPPool *v1alpha2.ExternalIPPool, opts v1.CreateOptions) (*v1alpha2.ExternalIPPool, error)
Update(ctx context.Context, externalIPPool *v1alpha2.ExternalIPPool, opts v1.UpdateOptions) (*v1alpha2.ExternalIPPool, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha2.ExternalIPPool, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha2.ExternalIPPoolList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha2.ExternalIPPool, err error)
ExternalIPPoolExpansion
}
ExternalIPPoolInterface has methods to work with ExternalIPPool resources.
type ExternalIPPoolsGetter ¶ added in v1.2.0
type ExternalIPPoolsGetter interface {
ExternalIPPools() ExternalIPPoolInterface
}
ExternalIPPoolsGetter has a method to return a ExternalIPPoolInterface. A group's client should implement this interface.