Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterGroupExpansion ¶
type ClusterGroupExpansion interface{}
type ClusterGroupInterface ¶
type ClusterGroupInterface interface {
Create(ctx context.Context, clusterGroup *v1alpha3.ClusterGroup, opts v1.CreateOptions) (*v1alpha3.ClusterGroup, error)
Update(ctx context.Context, clusterGroup *v1alpha3.ClusterGroup, opts v1.UpdateOptions) (*v1alpha3.ClusterGroup, error)
UpdateStatus(ctx context.Context, clusterGroup *v1alpha3.ClusterGroup, opts v1.UpdateOptions) (*v1alpha3.ClusterGroup, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha3.ClusterGroup, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha3.ClusterGroupList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha3.ClusterGroup, err error)
ClusterGroupExpansion
}
ClusterGroupInterface has methods to work with ClusterGroup resources.
type ClusterGroupsGetter ¶
type ClusterGroupsGetter interface {
ClusterGroups() ClusterGroupInterface
}
ClusterGroupsGetter has a method to return a ClusterGroupInterface. A group's client should implement this interface.
type CrdV1alpha3Client ¶
type CrdV1alpha3Client struct {
// contains filtered or unexported fields
}
CrdV1alpha3Client is used to interact with features provided by the crd.antrea.io group.
func New ¶
func New(c rest.Interface) *CrdV1alpha3Client
New creates a new CrdV1alpha3Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*CrdV1alpha3Client, error)
NewForConfig creates a new CrdV1alpha3Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶ added in v1.7.0
NewForConfigAndClient creates a new CrdV1alpha3Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *CrdV1alpha3Client
NewForConfigOrDie creates a new CrdV1alpha3Client for the given config and panics if there is an error in the config.
func (*CrdV1alpha3Client) ClusterGroups ¶
func (c *CrdV1alpha3Client) ClusterGroups() ClusterGroupInterface
func (*CrdV1alpha3Client) Groups ¶ added in v1.8.0
func (c *CrdV1alpha3Client) Groups(namespace string) GroupInterface
func (*CrdV1alpha3Client) RESTClient ¶
func (c *CrdV1alpha3Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type CrdV1alpha3Interface ¶
type CrdV1alpha3Interface interface {
RESTClient() rest.Interface
ClusterGroupsGetter
GroupsGetter
}
type GroupExpansion ¶ added in v1.8.0
type GroupExpansion interface{}
type GroupInterface ¶ added in v1.8.0
type GroupInterface interface {
Create(ctx context.Context, group *v1alpha3.Group, opts v1.CreateOptions) (*v1alpha3.Group, error)
Update(ctx context.Context, group *v1alpha3.Group, opts v1.UpdateOptions) (*v1alpha3.Group, error)
UpdateStatus(ctx context.Context, group *v1alpha3.Group, opts v1.UpdateOptions) (*v1alpha3.Group, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha3.Group, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha3.GroupList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha3.Group, err error)
GroupExpansion
}
GroupInterface has methods to work with Group resources.
type GroupsGetter ¶ added in v1.8.0
type GroupsGetter interface {
Groups(namespace string) GroupInterface
}
GroupsGetter has a method to return a GroupInterface. A group's client should implement this interface.