Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type AntreaAgentInfoExpansion
- type AntreaAgentInfoInterface
- type AntreaAgentInfosGetter
- type AntreaControllerInfoExpansion
- type AntreaControllerInfoInterface
- type AntreaControllerInfosGetter
- type ClusterGroupExpansion
- type ClusterGroupInterface
- type ClusterGroupsGetter
- type ClusterNetworkPoliciesGetter
- type ClusterNetworkPolicyExpansion
- type ClusterNetworkPolicyInterface
- type CrdV1beta1Client
- func (c *CrdV1beta1Client) AntreaAgentInfos() AntreaAgentInfoInterface
- func (c *CrdV1beta1Client) AntreaControllerInfos() AntreaControllerInfoInterface
- func (c *CrdV1beta1Client) ClusterGroups() ClusterGroupInterface
- func (c *CrdV1beta1Client) ClusterNetworkPolicies() ClusterNetworkPolicyInterface
- func (c *CrdV1beta1Client) Egresses() EgressInterface
- func (c *CrdV1beta1Client) ExternalIPPools() ExternalIPPoolInterface
- func (c *CrdV1beta1Client) Groups(namespace string) GroupInterface
- func (c *CrdV1beta1Client) NetworkPolicies(namespace string) NetworkPolicyInterface
- func (c *CrdV1beta1Client) RESTClient() rest.Interface
- func (c *CrdV1beta1Client) Tiers() TierInterface
- func (c *CrdV1beta1Client) Traceflows() TraceflowInterface
- type CrdV1beta1Interface
- type EgressExpansion
- type EgressInterface
- type EgressesGetter
- type ExternalIPPoolExpansion
- type ExternalIPPoolInterface
- type ExternalIPPoolsGetter
- type GroupExpansion
- type GroupInterface
- type GroupsGetter
- type NetworkPoliciesGetter
- type NetworkPolicyExpansion
- type NetworkPolicyInterface
- type TierExpansion
- type TierInterface
- type TiersGetter
- type TraceflowExpansion
- type TraceflowInterface
- type TraceflowsGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AntreaAgentInfoExpansion ¶
type AntreaAgentInfoExpansion interface{}
type AntreaAgentInfoInterface ¶
type AntreaAgentInfoInterface interface {
Create(ctx context.Context, antreaAgentInfo *v1beta1.AntreaAgentInfo, opts v1.CreateOptions) (*v1beta1.AntreaAgentInfo, error)
Update(ctx context.Context, antreaAgentInfo *v1beta1.AntreaAgentInfo, opts v1.UpdateOptions) (*v1beta1.AntreaAgentInfo, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.AntreaAgentInfo, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.AntreaAgentInfoList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.AntreaAgentInfo, err error)
AntreaAgentInfoExpansion
}
AntreaAgentInfoInterface has methods to work with AntreaAgentInfo resources.
type AntreaAgentInfosGetter ¶
type AntreaAgentInfosGetter interface {
AntreaAgentInfos() AntreaAgentInfoInterface
}
AntreaAgentInfosGetter has a method to return a AntreaAgentInfoInterface. A group's client should implement this interface.
type AntreaControllerInfoExpansion ¶
type AntreaControllerInfoExpansion interface{}
type AntreaControllerInfoInterface ¶
type AntreaControllerInfoInterface interface {
Create(ctx context.Context, antreaControllerInfo *v1beta1.AntreaControllerInfo, opts v1.CreateOptions) (*v1beta1.AntreaControllerInfo, error)
Update(ctx context.Context, antreaControllerInfo *v1beta1.AntreaControllerInfo, opts v1.UpdateOptions) (*v1beta1.AntreaControllerInfo, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.AntreaControllerInfo, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.AntreaControllerInfoList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.AntreaControllerInfo, err error)
AntreaControllerInfoExpansion
}
AntreaControllerInfoInterface has methods to work with AntreaControllerInfo resources.
type AntreaControllerInfosGetter ¶
type AntreaControllerInfosGetter interface {
AntreaControllerInfos() AntreaControllerInfoInterface
}
AntreaControllerInfosGetter has a method to return a AntreaControllerInfoInterface. A group's client should implement this interface.
type ClusterGroupExpansion ¶ added in v1.13.0
type ClusterGroupExpansion interface{}
type ClusterGroupInterface ¶ added in v1.13.0
type ClusterGroupInterface interface {
Create(ctx context.Context, clusterGroup *v1beta1.ClusterGroup, opts v1.CreateOptions) (*v1beta1.ClusterGroup, error)
Update(ctx context.Context, clusterGroup *v1beta1.ClusterGroup, opts v1.UpdateOptions) (*v1beta1.ClusterGroup, error)
UpdateStatus(ctx context.Context, clusterGroup *v1beta1.ClusterGroup, opts v1.UpdateOptions) (*v1beta1.ClusterGroup, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.ClusterGroup, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.ClusterGroupList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.ClusterGroup, err error)
ClusterGroupExpansion
}
ClusterGroupInterface has methods to work with ClusterGroup resources.
type ClusterGroupsGetter ¶ added in v1.13.0
type ClusterGroupsGetter interface {
ClusterGroups() ClusterGroupInterface
}
ClusterGroupsGetter has a method to return a ClusterGroupInterface. A group's client should implement this interface.
type ClusterNetworkPoliciesGetter ¶ added in v1.13.0
type ClusterNetworkPoliciesGetter interface {
ClusterNetworkPolicies() ClusterNetworkPolicyInterface
}
ClusterNetworkPoliciesGetter has a method to return a ClusterNetworkPolicyInterface. A group's client should implement this interface.
type ClusterNetworkPolicyExpansion ¶ added in v1.13.0
type ClusterNetworkPolicyExpansion interface{}
type ClusterNetworkPolicyInterface ¶ added in v1.13.0
type ClusterNetworkPolicyInterface interface {
Create(ctx context.Context, clusterNetworkPolicy *v1beta1.ClusterNetworkPolicy, opts v1.CreateOptions) (*v1beta1.ClusterNetworkPolicy, error)
Update(ctx context.Context, clusterNetworkPolicy *v1beta1.ClusterNetworkPolicy, opts v1.UpdateOptions) (*v1beta1.ClusterNetworkPolicy, error)
UpdateStatus(ctx context.Context, clusterNetworkPolicy *v1beta1.ClusterNetworkPolicy, opts v1.UpdateOptions) (*v1beta1.ClusterNetworkPolicy, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.ClusterNetworkPolicy, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.ClusterNetworkPolicyList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.ClusterNetworkPolicy, err error)
ClusterNetworkPolicyExpansion
}
ClusterNetworkPolicyInterface has methods to work with ClusterNetworkPolicy resources.
type CrdV1beta1Client ¶
type CrdV1beta1Client struct {
// contains filtered or unexported fields
}
CrdV1beta1Client is used to interact with features provided by the crd.antrea.io group.
func New ¶
func New(c rest.Interface) *CrdV1beta1Client
New creates a new CrdV1beta1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*CrdV1beta1Client, error)
NewForConfig creates a new CrdV1beta1Client for the given config. NewForConfig is equivalent to NewForConfigAndClient(c, httpClient), where httpClient was generated with rest.HTTPClientFor(c).
func NewForConfigAndClient ¶ added in v1.7.0
NewForConfigAndClient creates a new CrdV1beta1Client for the given config and http client. Note the http client provided takes precedence over the configured transport values.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *CrdV1beta1Client
NewForConfigOrDie creates a new CrdV1beta1Client for the given config and panics if there is an error in the config.
func (*CrdV1beta1Client) AntreaAgentInfos ¶
func (c *CrdV1beta1Client) AntreaAgentInfos() AntreaAgentInfoInterface
func (*CrdV1beta1Client) AntreaControllerInfos ¶
func (c *CrdV1beta1Client) AntreaControllerInfos() AntreaControllerInfoInterface
func (*CrdV1beta1Client) ClusterGroups ¶ added in v1.13.0
func (c *CrdV1beta1Client) ClusterGroups() ClusterGroupInterface
func (*CrdV1beta1Client) ClusterNetworkPolicies ¶ added in v1.13.0
func (c *CrdV1beta1Client) ClusterNetworkPolicies() ClusterNetworkPolicyInterface
func (*CrdV1beta1Client) Egresses ¶ added in v1.13.0
func (c *CrdV1beta1Client) Egresses() EgressInterface
func (*CrdV1beta1Client) ExternalIPPools ¶ added in v1.13.0
func (c *CrdV1beta1Client) ExternalIPPools() ExternalIPPoolInterface
func (*CrdV1beta1Client) Groups ¶ added in v1.13.0
func (c *CrdV1beta1Client) Groups(namespace string) GroupInterface
func (*CrdV1beta1Client) NetworkPolicies ¶ added in v1.13.0
func (c *CrdV1beta1Client) NetworkPolicies(namespace string) NetworkPolicyInterface
func (*CrdV1beta1Client) RESTClient ¶
func (c *CrdV1beta1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*CrdV1beta1Client) Tiers ¶ added in v1.13.0
func (c *CrdV1beta1Client) Tiers() TierInterface
func (*CrdV1beta1Client) Traceflows ¶ added in v1.13.0
func (c *CrdV1beta1Client) Traceflows() TraceflowInterface
type CrdV1beta1Interface ¶
type CrdV1beta1Interface interface {
RESTClient() rest.Interface
AntreaAgentInfosGetter
AntreaControllerInfosGetter
ClusterGroupsGetter
ClusterNetworkPoliciesGetter
EgressesGetter
ExternalIPPoolsGetter
GroupsGetter
NetworkPoliciesGetter
TiersGetter
TraceflowsGetter
}
type EgressExpansion ¶ added in v1.13.0
type EgressExpansion interface{}
type EgressInterface ¶ added in v1.13.0
type EgressInterface interface {
Create(ctx context.Context, egress *v1beta1.Egress, opts v1.CreateOptions) (*v1beta1.Egress, error)
Update(ctx context.Context, egress *v1beta1.Egress, opts v1.UpdateOptions) (*v1beta1.Egress, error)
UpdateStatus(ctx context.Context, egress *v1beta1.Egress, opts v1.UpdateOptions) (*v1beta1.Egress, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.Egress, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.EgressList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.Egress, err error)
EgressExpansion
}
EgressInterface has methods to work with Egress resources.
type EgressesGetter ¶ added in v1.13.0
type EgressesGetter interface {
Egresses() EgressInterface
}
EgressesGetter has a method to return a EgressInterface. A group's client should implement this interface.
type ExternalIPPoolExpansion ¶ added in v1.13.0
type ExternalIPPoolExpansion interface{}
type ExternalIPPoolInterface ¶ added in v1.13.0
type ExternalIPPoolInterface interface {
Create(ctx context.Context, externalIPPool *v1beta1.ExternalIPPool, opts v1.CreateOptions) (*v1beta1.ExternalIPPool, error)
Update(ctx context.Context, externalIPPool *v1beta1.ExternalIPPool, opts v1.UpdateOptions) (*v1beta1.ExternalIPPool, error)
UpdateStatus(ctx context.Context, externalIPPool *v1beta1.ExternalIPPool, opts v1.UpdateOptions) (*v1beta1.ExternalIPPool, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.ExternalIPPool, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.ExternalIPPoolList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.ExternalIPPool, err error)
ExternalIPPoolExpansion
}
ExternalIPPoolInterface has methods to work with ExternalIPPool resources.
type ExternalIPPoolsGetter ¶ added in v1.13.0
type ExternalIPPoolsGetter interface {
ExternalIPPools() ExternalIPPoolInterface
}
ExternalIPPoolsGetter has a method to return a ExternalIPPoolInterface. A group's client should implement this interface.
type GroupExpansion ¶ added in v1.13.0
type GroupExpansion interface{}
type GroupInterface ¶ added in v1.13.0
type GroupInterface interface {
Create(ctx context.Context, group *v1beta1.Group, opts v1.CreateOptions) (*v1beta1.Group, error)
Update(ctx context.Context, group *v1beta1.Group, opts v1.UpdateOptions) (*v1beta1.Group, error)
UpdateStatus(ctx context.Context, group *v1beta1.Group, opts v1.UpdateOptions) (*v1beta1.Group, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.Group, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.GroupList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.Group, err error)
GroupExpansion
}
GroupInterface has methods to work with Group resources.
type GroupsGetter ¶ added in v1.13.0
type GroupsGetter interface {
Groups(namespace string) GroupInterface
}
GroupsGetter has a method to return a GroupInterface. A group's client should implement this interface.
type NetworkPoliciesGetter ¶ added in v1.13.0
type NetworkPoliciesGetter interface {
NetworkPolicies(namespace string) NetworkPolicyInterface
}
NetworkPoliciesGetter has a method to return a NetworkPolicyInterface. A group's client should implement this interface.
type NetworkPolicyExpansion ¶ added in v1.13.0
type NetworkPolicyExpansion interface{}
type NetworkPolicyInterface ¶ added in v1.13.0
type NetworkPolicyInterface interface {
Create(ctx context.Context, networkPolicy *v1beta1.NetworkPolicy, opts v1.CreateOptions) (*v1beta1.NetworkPolicy, error)
Update(ctx context.Context, networkPolicy *v1beta1.NetworkPolicy, opts v1.UpdateOptions) (*v1beta1.NetworkPolicy, error)
UpdateStatus(ctx context.Context, networkPolicy *v1beta1.NetworkPolicy, opts v1.UpdateOptions) (*v1beta1.NetworkPolicy, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.NetworkPolicy, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.NetworkPolicyList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.NetworkPolicy, err error)
NetworkPolicyExpansion
}
NetworkPolicyInterface has methods to work with NetworkPolicy resources.
type TierExpansion ¶ added in v1.13.0
type TierExpansion interface{}
type TierInterface ¶ added in v1.13.0
type TierInterface interface {
Create(ctx context.Context, tier *v1beta1.Tier, opts v1.CreateOptions) (*v1beta1.Tier, error)
Update(ctx context.Context, tier *v1beta1.Tier, opts v1.UpdateOptions) (*v1beta1.Tier, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.Tier, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.TierList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.Tier, err error)
TierExpansion
}
TierInterface has methods to work with Tier resources.
type TiersGetter ¶ added in v1.13.0
type TiersGetter interface {
Tiers() TierInterface
}
TiersGetter has a method to return a TierInterface. A group's client should implement this interface.
type TraceflowExpansion ¶ added in v1.13.0
type TraceflowExpansion interface{}
type TraceflowInterface ¶ added in v1.13.0
type TraceflowInterface interface {
Create(ctx context.Context, traceflow *v1beta1.Traceflow, opts v1.CreateOptions) (*v1beta1.Traceflow, error)
Update(ctx context.Context, traceflow *v1beta1.Traceflow, opts v1.UpdateOptions) (*v1beta1.Traceflow, error)
UpdateStatus(ctx context.Context, traceflow *v1beta1.Traceflow, opts v1.UpdateOptions) (*v1beta1.Traceflow, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.Traceflow, error)
List(ctx context.Context, opts v1.ListOptions) (*v1beta1.TraceflowList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.Traceflow, err error)
TraceflowExpansion
}
TraceflowInterface has methods to work with Traceflow resources.
type TraceflowsGetter ¶ added in v1.13.0
type TraceflowsGetter interface {
Traceflows() TraceflowInterface
}
TraceflowsGetter has a method to return a TraceflowInterface. A group's client should implement this interface.