Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Options ¶
type Options struct {
// The configuration object
Config *flowaggregatorconfig.FlowAggregatorConfig
// Expiration timeout for active flow records in the flow aggregator
ActiveFlowRecordTimeout time.Duration
// Expiration timeout for inactive flow records in the flow aggregator
InactiveFlowRecordTimeout time.Duration
// Transport protocol over which the aggregator collects IPFIX records from all Agents
AggregatorTransportProtocol flowaggregatorconfig.AggregatorTransportProtocol
// IPFIX flow collector address
ExternalFlowCollectorAddr string
// IPFIX flow collector transport protocol
ExternalFlowCollectorProto string
// clickHouseCommitInterval flow records batch commit interval to clickhouse in the flow aggregator
ClickHouseCommitInterval time.Duration
// Flow records batch upload interval from flow aggregator to S3 bucket
S3UploadInterval time.Duration
}
func LoadConfig ¶
Click to show internal directories.
Click to hide internal directories.