Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewIPFIXRegistry ¶
func NewIPFIXRegistry() *ipfixRegistry
Types ¶
type IPFIXAggregationProcess ¶
type IPFIXAggregationProcess interface {
Start()
Stop()
ForAllExpiredFlowRecordsDo(callback ipfixintermediate.FlowKeyRecordMapCallBack) error
GetExpiryFromExpirePriorityQueue() time.Duration
GetRecords(flowKey *ipfixintermediate.FlowKey) []map[string]interface{}
ResetStatAndThroughputElementsInRecord(record ipfixentities.Record) error
IsAggregatedRecordIPv4(record ipfixintermediate.AggregationFlowRecord) bool
SetExternalFieldsFilled(record *ipfixintermediate.AggregationFlowRecord, isFilled bool)
AreExternalFieldsFilled(record ipfixintermediate.AggregationFlowRecord) bool
GetNumFlows() int64
}
IPFIXAggregationProcess interface is added to facilitate unit testing without involving the code from go-ipfix library.
type IPFIXCollectingProcess ¶
type IPFIXCollectingProcess interface {
Start()
Stop()
GetMsgChan() chan *ipfixentities.Message
GetNumRecordsReceived() int64
GetNumConnToCollector() int64
}
IPFIXCollectingProcess interface is added to facilitate unit testing without involving the code from go-ipfix library.
type IPFIXExportingProcess ¶
type IPFIXExportingProcess interface {
NewTemplateID() uint16
SendSet(set ipfixentities.Set) (int, error)
CloseConnToCollector()
}
IPFIXExportingProcess interface is added to facilitate unit testing without involving the code from go-ipfix library.
type IPFIXRegistry ¶
type IPFIXRegistry interface {
LoadRegistry()
GetInfoElement(name string, enterpriseID uint32) (*ipfixentities.InfoElement, error)
}
IPFIXRegistry interface is added to facilitate unit testing without involving the code from go-ipfix library.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.