Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterGroupExpansion ¶
type ClusterGroupExpansion interface{}
type ClusterGroupInterface ¶
type ClusterGroupInterface interface {
Create(ctx context.Context, clusterGroup *v1alpha2.ClusterGroup, opts v1.CreateOptions) (*v1alpha2.ClusterGroup, error)
Update(ctx context.Context, clusterGroup *v1alpha2.ClusterGroup, opts v1.UpdateOptions) (*v1alpha2.ClusterGroup, error)
UpdateStatus(ctx context.Context, clusterGroup *v1alpha2.ClusterGroup, opts v1.UpdateOptions) (*v1alpha2.ClusterGroup, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha2.ClusterGroup, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha2.ClusterGroupList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha2.ClusterGroup, err error)
ClusterGroupExpansion
}
ClusterGroupInterface has methods to work with ClusterGroup resources.
type ClusterGroupsGetter ¶
type ClusterGroupsGetter interface {
ClusterGroups() ClusterGroupInterface
}
ClusterGroupsGetter has a method to return a ClusterGroupInterface. A group's client should implement this interface.
type CoreV1alpha2Client ¶
type CoreV1alpha2Client struct {
// contains filtered or unexported fields
}
CoreV1alpha2Client is used to interact with features provided by the core.antrea.tanzu.vmware.com group.
func New ¶
func New(c rest.Interface) *CoreV1alpha2Client
New creates a new CoreV1alpha2Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*CoreV1alpha2Client, error)
NewForConfig creates a new CoreV1alpha2Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *CoreV1alpha2Client
NewForConfigOrDie creates a new CoreV1alpha2Client for the given config and panics if there is an error in the config.
func (*CoreV1alpha2Client) ClusterGroups ¶
func (c *CoreV1alpha2Client) ClusterGroups() ClusterGroupInterface
func (*CoreV1alpha2Client) ExternalEntities ¶
func (c *CoreV1alpha2Client) ExternalEntities(namespace string) ExternalEntityInterface
func (*CoreV1alpha2Client) RESTClient ¶
func (c *CoreV1alpha2Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type CoreV1alpha2Interface ¶
type CoreV1alpha2Interface interface {
RESTClient() rest.Interface
ClusterGroupsGetter
ExternalEntitiesGetter
}
type ExternalEntitiesGetter ¶
type ExternalEntitiesGetter interface {
ExternalEntities(namespace string) ExternalEntityInterface
}
ExternalEntitiesGetter has a method to return a ExternalEntityInterface. A group's client should implement this interface.
type ExternalEntityExpansion ¶
type ExternalEntityExpansion interface{}
type ExternalEntityInterface ¶
type ExternalEntityInterface interface {
Create(ctx context.Context, externalEntity *v1alpha2.ExternalEntity, opts v1.CreateOptions) (*v1alpha2.ExternalEntity, error)
Update(ctx context.Context, externalEntity *v1alpha2.ExternalEntity, opts v1.UpdateOptions) (*v1alpha2.ExternalEntity, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha2.ExternalEntity, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha2.ExternalEntityList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha2.ExternalEntity, err error)
ExternalEntityExpansion
}
ExternalEntityInterface has methods to work with ExternalEntity resources.