Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
- type ClusterNetworkPoliciesGetter
- type ClusterNetworkPolicyExpansion
- type ClusterNetworkPolicyInterface
- type NetworkPoliciesGetter
- type NetworkPolicyExpansion
- type NetworkPolicyInterface
- type SecurityV1alpha1Client
- type SecurityV1alpha1Interface
- type TierExpansion
- type TierInterface
- type TiersGetter
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterNetworkPoliciesGetter ¶
type ClusterNetworkPoliciesGetter interface {
ClusterNetworkPolicies() ClusterNetworkPolicyInterface
}
ClusterNetworkPoliciesGetter has a method to return a ClusterNetworkPolicyInterface. A group's client should implement this interface.
type ClusterNetworkPolicyExpansion ¶
type ClusterNetworkPolicyExpansion interface{}
type ClusterNetworkPolicyInterface ¶
type ClusterNetworkPolicyInterface interface {
Create(ctx context.Context, clusterNetworkPolicy *v1alpha1.ClusterNetworkPolicy, opts v1.CreateOptions) (*v1alpha1.ClusterNetworkPolicy, error)
Update(ctx context.Context, clusterNetworkPolicy *v1alpha1.ClusterNetworkPolicy, opts v1.UpdateOptions) (*v1alpha1.ClusterNetworkPolicy, error)
UpdateStatus(ctx context.Context, clusterNetworkPolicy *v1alpha1.ClusterNetworkPolicy, opts v1.UpdateOptions) (*v1alpha1.ClusterNetworkPolicy, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.ClusterNetworkPolicy, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.ClusterNetworkPolicyList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.ClusterNetworkPolicy, err error)
ClusterNetworkPolicyExpansion
}
ClusterNetworkPolicyInterface has methods to work with ClusterNetworkPolicy resources.
type NetworkPoliciesGetter ¶
type NetworkPoliciesGetter interface {
NetworkPolicies(namespace string) NetworkPolicyInterface
}
NetworkPoliciesGetter has a method to return a NetworkPolicyInterface. A group's client should implement this interface.
type NetworkPolicyExpansion ¶
type NetworkPolicyExpansion interface{}
type NetworkPolicyInterface ¶
type NetworkPolicyInterface interface {
Create(ctx context.Context, networkPolicy *v1alpha1.NetworkPolicy, opts v1.CreateOptions) (*v1alpha1.NetworkPolicy, error)
Update(ctx context.Context, networkPolicy *v1alpha1.NetworkPolicy, opts v1.UpdateOptions) (*v1alpha1.NetworkPolicy, error)
UpdateStatus(ctx context.Context, networkPolicy *v1alpha1.NetworkPolicy, opts v1.UpdateOptions) (*v1alpha1.NetworkPolicy, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.NetworkPolicy, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.NetworkPolicyList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.NetworkPolicy, err error)
NetworkPolicyExpansion
}
NetworkPolicyInterface has methods to work with NetworkPolicy resources.
type SecurityV1alpha1Client ¶
type SecurityV1alpha1Client struct {
// contains filtered or unexported fields
}
SecurityV1alpha1Client is used to interact with features provided by the security.antrea.tanzu.vmware.com group.
func New ¶
func New(c rest.Interface) *SecurityV1alpha1Client
New creates a new SecurityV1alpha1Client for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*SecurityV1alpha1Client, error)
NewForConfig creates a new SecurityV1alpha1Client for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *SecurityV1alpha1Client
NewForConfigOrDie creates a new SecurityV1alpha1Client for the given config and panics if there is an error in the config.
func (*SecurityV1alpha1Client) ClusterNetworkPolicies ¶
func (c *SecurityV1alpha1Client) ClusterNetworkPolicies() ClusterNetworkPolicyInterface
func (*SecurityV1alpha1Client) NetworkPolicies ¶
func (c *SecurityV1alpha1Client) NetworkPolicies(namespace string) NetworkPolicyInterface
func (*SecurityV1alpha1Client) RESTClient ¶
func (c *SecurityV1alpha1Client) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*SecurityV1alpha1Client) Tiers ¶
func (c *SecurityV1alpha1Client) Tiers() TierInterface
type SecurityV1alpha1Interface ¶
type SecurityV1alpha1Interface interface {
RESTClient() rest.Interface
ClusterNetworkPoliciesGetter
NetworkPoliciesGetter
TiersGetter
}
type TierExpansion ¶
type TierExpansion interface{}
type TierInterface ¶
type TierInterface interface {
Create(ctx context.Context, tier *v1alpha1.Tier, opts v1.CreateOptions) (*v1alpha1.Tier, error)
Update(ctx context.Context, tier *v1alpha1.Tier, opts v1.UpdateOptions) (*v1alpha1.Tier, error)
Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
Get(ctx context.Context, name string, opts v1.GetOptions) (*v1alpha1.Tier, error)
List(ctx context.Context, opts v1.ListOptions) (*v1alpha1.TierList, error)
Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1alpha1.Tier, err error)
TierExpansion
}
TierInterface has methods to work with Tier resources.
type TiersGetter ¶
type TiersGetter interface {
Tiers() TierInterface
}
TiersGetter has a method to return a TierInterface. A group's client should implement this interface.