Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewFilteredTraceflowInformer ¶
func NewFilteredTraceflowInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredTraceflowInformer constructs a new informer for Traceflow type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewTraceflowInformer ¶
func NewTraceflowInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewTraceflowInformer constructs a new informer for Traceflow type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type Interface ¶
type Interface interface {
// Traceflows returns a TraceflowInformer.
Traceflows() TraceflowInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type TraceflowInformer ¶
type TraceflowInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.TraceflowLister
}
TraceflowInformer provides access to a shared informer and lister for Traceflows.