Documentation
¶
Index ¶
- func NewClusterNetworkPolicyInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredClusterNetworkPolicyInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredNetworkPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewFilteredTierInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewNetworkPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- func NewTierInformer(client versioned.Interface, resyncPeriod time.Duration, ...) cache.SharedIndexInformer
- type ClusterNetworkPolicyInformer
- type Interface
- type NetworkPolicyInformer
- type TierInformer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewClusterNetworkPolicyInformer ¶
func NewClusterNetworkPolicyInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewClusterNetworkPolicyInformer constructs a new informer for ClusterNetworkPolicy type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredClusterNetworkPolicyInformer ¶
func NewFilteredClusterNetworkPolicyInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredClusterNetworkPolicyInformer constructs a new informer for ClusterNetworkPolicy type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredNetworkPolicyInformer ¶
func NewFilteredNetworkPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredNetworkPolicyInformer constructs a new informer for NetworkPolicy type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewFilteredTierInformer ¶
func NewFilteredTierInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers, tweakListOptions internalinterfaces.TweakListOptionsFunc) cache.SharedIndexInformer
NewFilteredTierInformer constructs a new informer for Tier type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewNetworkPolicyInformer ¶
func NewNetworkPolicyInformer(client versioned.Interface, namespace string, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewNetworkPolicyInformer constructs a new informer for NetworkPolicy type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
func NewTierInformer ¶
func NewTierInformer(client versioned.Interface, resyncPeriod time.Duration, indexers cache.Indexers) cache.SharedIndexInformer
NewTierInformer constructs a new informer for Tier type. Always prefer using an informer factory to get a shared informer instead of getting an independent one. This reduces memory footprint and number of connections to the server.
Types ¶
type ClusterNetworkPolicyInformer ¶
type ClusterNetworkPolicyInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.ClusterNetworkPolicyLister
}
ClusterNetworkPolicyInformer provides access to a shared informer and lister for ClusterNetworkPolicies.
type Interface ¶
type Interface interface {
// ClusterNetworkPolicies returns a ClusterNetworkPolicyInformer.
ClusterNetworkPolicies() ClusterNetworkPolicyInformer
// NetworkPolicies returns a NetworkPolicyInformer.
NetworkPolicies() NetworkPolicyInformer
// Tiers returns a TierInformer.
Tiers() TierInformer
}
Interface provides access to all the informers in this group version.
func New ¶
func New(f internalinterfaces.SharedInformerFactory, namespace string, tweakListOptions internalinterfaces.TweakListOptionsFunc) Interface
New returns a new Interface.
type NetworkPolicyInformer ¶
type NetworkPolicyInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.NetworkPolicyLister
}
NetworkPolicyInformer provides access to a shared informer and lister for NetworkPolicies.
type TierInformer ¶
type TierInformer interface {
Informer() cache.SharedIndexInformer
Lister() v1alpha1.TierLister
}
TierInformer provides access to a shared informer and lister for Tiers.