Affected by GO-2026-4461
and 2 other vulnerabilities
GO-2026-4461 : Antrea has invalid enforcement order for network policy rules caused by integer overflow in antrea.io/antrea
GO-2026-5579 : Antrea has Missing Encryption of Sensitive Data in antrea.io/antrea
GO-2026-5579 : Antrea has Missing Encryption of Sensitive Data in antrea.io/antrea
The highest tagged major version is
v2 .
Discover Packages
antrea.io/antrea
pkg
util
lazy
package
Version:
v1.15.2
Opens a new window with list of versions in this module.
Published: Jun 21, 2024
License: Apache-2.0
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
type Lazy[T any ] interface {
Get() T
Evaluated() bool
}
Lazy defers the evaluation of getter until it's accessed the first access.
func New[T any ](getter func() T) Lazy [T]
New returns a new lazily evaluated value. The getter is executed only when it's accessed the first access.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.